<?php
/*
Plugin Name: Remove Recent Media
Description: Preview and remove media files uploaded in a custom timeframe.
Version: 2.9
Author: DrGlenn
Author URI: https://fixmyhackedwebsite.com
*/

if (!defined('ABSPATH')) exit;

function rrm_add_admin_menu() {
    add_management_page('Remove Recent Media', 'Remove Recent Media', 'manage_options', 'remove-recent-media', 'rrm_render_admin_page');
}
add_action('admin_menu', 'rrm_add_admin_menu');

function rrm_render_admin_page() {
    if (!current_user_can('manage_options')) return;

    $time_options = array_merge(
        array_map(fn($h) => "$h hour" . ($h > 1 ? 's' : ''), range(1, 23)),
        array_map(fn($d) => "$d day" . ($d > 1 ? 's' : ''), range(1, 30)),
        array_map(fn($w) => "$w week" . ($w > 1 ? 's' : ''), range(1, 4)),
        array_map(fn($m) => "$m month" . ($m > 1 ? 's' : ''), range(1, 11)),
        ['1 year', '2 years']
    );

    $selected_time = $_POST['rrm_range'] ?? '2 hours';
    $show_thumbs_requested = isset($_POST['rrm_show_thumbs']);
    $confirm_thumbs = isset($_POST['rrm_confirm_thumbs']);
    $per_page = isset($_POST['rrm_per_page']) ? ($_POST['rrm_per_page'] === 'all' ? 'all' : (int) $_POST['rrm_per_page']) : 50;
    $page = isset($_POST['rrm_page']) ? (int) $_POST['rrm_page'] : 1;

    $media_all = rrm_get_recent_media($selected_time);
    $media_count = count($media_all);

    $thumb_threshold = 200;
    $exceeds_threshold = ($per_page === 'all' || $per_page > $thumb_threshold);
    $show_thumbs = $show_thumbs_requested && (!$exceeds_threshold || $confirm_thumbs);

    if ($per_page === 'all') {
        $paged_media = $media_all;
        $total_pages = 1;
    } else {
        $start = ($page - 1) * $per_page;
        $paged_media = array_slice($media_all, $start, $per_page);
        $total_pages = ceil($media_count / $per_page);
    }

    echo '<div class="wrap">';
    echo '<h1>Remove Recent Media</h1>';
    echo '<p>Select how far back you want to remove media uploads from:</p>';

    echo '<form method="post">';
    wp_nonce_field('rrm_remove_recent');
    echo '<select name="rrm_range">';
    foreach ($time_options as $option) {
        $selected = ($option === $selected_time) ? 'selected' : '';
        echo '<option value="' . esc_attr($option) . '" ' . $selected . '>' . esc_html($option) . '</option>';
    }
    echo '</select> ';
    echo '<label><input type="checkbox" name="rrm_show_thumbs" value="1"' . ($show_thumbs_requested ? ' checked' : '') . '> Show thumbnails</label> ';
    echo '<select name="rrm_per_page">';
    foreach ([25, 50, 100, 200, 500, 1000, 'all'] as $val) {
        $selected = ($val === $per_page) ? 'selected' : '';
        $label = ($val === 'all') ? 'All' : $val . ' per page';
        echo '<option value="' . $val . '" ' . $selected . '>' . $label . '</option>';
    }
    echo '</select> ';
    if ($show_thumbs_requested && $exceeds_threshold && !$confirm_thumbs) {
        echo '<input type="hidden" name="rrm_confirm_thumbs" value="1">';
        echo '<div class="notice notice-warning" style="margin-top: 10px;"><p>⚠️ You have selected more than ' . $thumb_threshold . ' items with thumbnails enabled. This may slow down your browser or consume excessive memory. Click again to proceed anyway.</p></div>';
    }
    echo '<input type="submit" class="button" value="Preview Files">';
    echo '</form>';

    echo '<div class="notice notice-info"><p>🧪 Found ' . $media_count . ' media file(s) from the last ' . esc_html($selected_time) . '.</p></div>';

    if (!empty($paged_media)) {
        echo '<form method="post">';
        wp_nonce_field('rrm_remove_recent');
        echo '<input type="hidden" name="rrm_range" value="' . esc_attr($selected_time) . '">';
        echo '<input type="hidden" name="rrm_show_thumbs" value="' . ($show_thumbs_requested ? '1' : '') . '">';
        echo '<input type="hidden" name="rrm_confirm_thumbs" value="1">';
        echo '<input type="hidden" name="rrm_per_page" value="' . esc_attr($per_page) . '">';
        echo '<input type="hidden" name="rrm_page" value="' . esc_attr($page) . '">';
        echo '<input type="hidden" name="rrm_remove_all" value="1">';
        submit_button('🔥 Delete All Files Listed Below', 'delete');
        echo '</form>';

        echo '<h2>Page ' . $page . ' of ' . $total_pages . '</h2>';
        echo '<form method="post">';
        wp_nonce_field('rrm_remove_recent');
        echo '<input type="hidden" name="rrm_range" value="' . esc_attr($selected_time) . '">';
        echo '<input type="hidden" name="rrm_show_thumbs" value="' . ($show_thumbs_requested ? '1' : '') . '">';
        echo '<input type="hidden" name="rrm_confirm_thumbs" value="1">';
        echo '<input type="hidden" name="rrm_per_page" value="' . esc_attr($per_page) . '">';
        echo '<input type="hidden" name="rrm_page" value="' . esc_attr($page) . '">';
        echo '<div style="display: flex; flex-wrap: wrap; gap: 10px;">';
        foreach ($paged_media as $item) {
            $url = wp_get_attachment_url($item->ID);
            $thumb = $show_thumbs ? wp_get_attachment_image($item->ID, 'thumbnail', false, ['style' => 'max-width:100%; height:auto;']) : '';
            $time = get_the_time('Y-m-d H:i:s', $item);
            echo '<div style="width: 180px; border: 1px solid #ccc; padding: 5px; text-align: center;">';
            echo $thumb;
            echo '<div><label><input type="checkbox" name="rrm_selected[]" value="' . esc_attr($item->ID) . '"> Delete</label></div>';
            echo '<div style="font-size: 0.85em; word-wrap: break-word;">' . esc_html($item->post_title) . '</div>';
            echo '<div style="font-size: 0.8em; color: #666;">' . esc_html($time) . '</div>';
            echo '<div><a href="' . esc_url($url) . '" target="_blank">View</a></div>';
            echo '</div>';
        }
        echo '</div>';
        echo '<input type="hidden" name="rrm_remove" value="1">';
        submit_button('Delete Selected Media Files');
        echo '</form>';

        if ($total_pages > 1 && $per_page !== 'all') {
            echo '<form method="post" style="margin-top:20px;">';
            echo '<input type="hidden" name="rrm_range" value="' . esc_attr($selected_time) . '">';
            echo '<input type="hidden" name="rrm_show_thumbs" value="' . ($show_thumbs_requested ? '1' : '') . '">';
            echo '<input type="hidden" name="rrm_confirm_thumbs" value="1">';
            echo '<input type="hidden" name="rrm_per_page" value="' . esc_attr($per_page) . '">';
            echo '<strong>Page: </strong>';
            for ($i = 1; $i <= $total_pages; $i++) {
                echo '<button name="rrm_page" value="' . $i . '" class="button' . ($i == $page ? ' button-primary' : '') . '">' . $i . '</button> ';
            }
            echo '</form>';
        }
    } else {
        echo '<p>No media files found for that time range.</p>';
    }

    echo '</div>';
}

function rrm_get_recent_media($timeframe = '2 hours') {
    $timestamp = strtotime("-" . $timeframe);
    if (!$timestamp) return [];

    return get_posts([
        'post_type' => 'attachment',
        'post_status' => 'inherit',
        'date_query' => [
            [
                'column' => 'post_date',
                'after' => date('Y-m-d H:i:s', $timestamp),
                'inclusive' => true
            ]
        ],
        'orderby' => 'date',
        'order' => 'DESC',
        'posts_per_page' => -1
    ]);
}

function rrm_delete_recent_media($timeframe = '2 hours') {
    $count = 0;
    if (!empty($_POST['rrm_selected']) && is_array($_POST['rrm_selected'])) {
        foreach ($_POST['rrm_selected'] as $media_id) {
            if (wp_delete_attachment((int)$media_id, true)) {
                $count++;
            }
        }
    }
    if (isset($_POST['rrm_remove_all']) && $_POST['rrm_remove_all'] === '1') {
        $media_all = rrm_get_recent_media($_POST['rrm_range'] ?? '2 hours');
        foreach ($media_all as $item) {
            if (wp_delete_attachment($item->ID, true)) {
                $count++;
            }
        }
    }
    return $count;
}
